#
# spec file for package python-Flask-WTF
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%bcond_without     test
Name:           python-Flask-WTF
Version:        0.14.3
Release:        1.9
Summary:        WTForms support for Flask
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/lepture/flask-wtf
Source:         https://files.pythonhosted.org/packages/source/F/Flask-WTF/Flask-WTF-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask
Requires:       python-WTForms
Requires:       python-Werkzeug
Requires:       python-itsdangerous
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Flask-Babel}
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module WTForms}
BuildRequires:  %{python_module Werkzeug}
BuildRequires:  %{python_module itsdangerous}
BuildRequires:  %{python_module pytest}
%endif
%python_subpackages

%description
Adds WTForms support to your Flask application

%prep
%setup -q -n Flask-WTF-%{version}

%build
%python_build

%install
%python_install
%fdupes %{buildroot}%{_prefix}

%if %{with test}
%check
export LANG=en_US.UTF-8
%pytest tests
%endif

%files %{python_files}
%license LICENSE
%doc AUTHORS README.rst
%{python_sitelib}/flask_wtf
%{python_sitelib}/Flask_WTF-%{version}-py*.egg-info

%changelog
* Thu Jan 28 2021 alarrosa@suse.com
- Define skip_python2 so we can build the package for SLE where an
  old version of python2-Flask-Babel is available (and doesn't work
  with a recent python-Werkzeug)
* Wed Jun 10 2020 mcalabkova@suse.com
- replace nose with pytest
* Sat Feb  8 2020 arun@gmx.de
- specfile:
  * update copyright year
  * removed python-devel dependency
  * be more specific in %%file section
- update to version 0.14.3:
  * Fix deprecated imports from "werkzeug" and "collections".
* Thu Jan 25 2018 tchvatal@suse.com
- Fix whitespace and drop the subpkg wrt previous commit
* Wed Jan 24 2018 aboe76@gmail.com
- Added python-itsdangerous requirements
- disabled sphinx build html docs and doc packages because of build errors.
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to Version 0.14.2
  * Fix bug where ``FlaskForm`` assumed ``meta`` argument was not ``None`` if it
    was passed. (`#278`_)
- Update to Version 0.14.1
  * Fix bug where the file validators would incorrectly identify an empty file as
    valid data. (`#276`_, `#277`_)
- Update to Version 0.14
  * Use itsdangerous to sign CSRF tokens and check expiration instead of doing it
    ourselves. (`#264`_)
  * Remove the ``app`` attribute from ``CsrfProtect``, use ``current_app``.
    (`#264`_)
  * ``CsrfProtect`` protects the ``DELETE`` method by default. (`#264`_)
  * The same CSRF token is generated for the lifetime of a request. It is exposed
    as ``request.csrf_token`` for use during testing. (`#227`_, `#264`_)
  * ``CsrfProtect.error_handler`` is deprecated. (`#264`_)
  * Use ``Form.Meta`` instead of deprecated ``SecureForm`` for CSRF (and
    everything else). (`#216`_, `#271`_)
  * Provide ``WTF_CSRF_FIELD_NAME`` to configure the name of the CSRF token.
    (`#271`_)
  * ``validate_csrf`` raises ``wtforms.ValidationError`` with specific messages
    instead of returning ``True`` or ``False``. This breaks anything that was
    calling the method directly. (`#239`_, `#271`_)
  * ``CsrfProtect`` is renamed to ``CSRFProtect``. A deprecation warning is issued
    when using the old name. ``CsrfError`` is renamed to ``CSRFError`` without
    deprecation. (`#271`_)
  * ``FileField`` is deprecated because it no longer provides functionality over
    the provided validators. Use ``wtforms.FileField`` directly. (`#272`_)
- Update to Version 0.13.1
  * Deprecation warning for ``Form`` is shown during ``__init__`` instead of immediately when subclassing. (`#262`_)
  * Don't use ``pkg_resources`` to get version, for compatibility with GAE. (`#261`_)
- Update to Version 0.13
  * ``Form`` is renamed to ``FlaskForm`` in order to avoid name collision with WTForms's base class.  Using ``Form`` will show a deprecation warning. (`#250`_)
  * ``hidden_tag`` no longer wraps the hidden inputs in a hidden div.  This is valid HTML5 and any modern HTML parser will behave correctly. (`#217`_, `#193`_)
  * ``flask_wtf.html5`` is deprecated.  Import directly from ``wtforms.fields.html5``. (`#251`_)
  * ``is_submitted`` is true for ``PATCH`` and ``DELETE`` in addition to ``POST`` and ``PUT``. (`#187`_)
  * ``generate_csrf`` takes a ``token_key`` parameter to specify the key stored in the session. (`#206`_)
  * ``generate_csrf`` takes a ``url_safe`` parameter to allow the token to be used in URLs. (`#206`_)
  * ``form.data`` can be accessed multiple times without raising an exception. (`#248`_)
  * File extension with multiple parts (``.tar.gz``) can be used in the ``FileAllowed`` validator. (`#201`_)
- Update to Version 0.12
  * Abstract protect_csrf() into a separate method
  * Update reCAPTCHA configuration
  * Fix reCAPTCHA error handle
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Wed Mar 25 2015 aboe76@gmail.com
- Updated to 0.11
  - Use the new reCAPTCHA API via #164.
  - Add configuration: WTF_CSRF_HEADERS via #159.
  - Support customize hidden tags via #150.
  - And many more bug fixes
* Wed Oct 22 2014 aboe76@gmail.com
- Updated to 0.10.2
  - Update translation for reCaptcha via #146.
  - Update RECAPTCHA API SERVER URL via #145.
  - Update requirement Werkzeug>=0.9.5
  - Fix CsrfProtect exempt for blueprints via #143.
  - Add configuration: WTF_CSRF_METHODS
  - Support WTForms 2.0 now
  - Fix csrf validation without time limit (time_limit=False)
  - CSRF exempt supports blueprint #111.
* Wed Jul  2 2014 aboe76@gmail.com
- Updated to 0.9.5
- Add configuration: WTF_CSRF_METHODS.
* Wed Feb 12 2014 aboe76@gmail.com
- Initial Upload: Flask-WTF 0.8.4 Released 2013/12/20
- Bugfix for csrf module when form has a prefix
- Compatible support for wtforms2
- Remove file API for FileField
